@@ -9,7 +9,7 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
-class ElementCount(Constraint):
+class ElementCount(Constraint[list]):
     element_count: int
 
     def __init__(self, element_count: int):
