@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, Type
+from typing import TYPE_CHECKING, Optional
 from uuid import UUID
 
 from sila2.framework.abc.data_type import DataType
@@ -8,20 +8,17 @@ from sila2.framework.abc.named_data_node import NamedDataNode
 from sila2.framework.command.intermediate_response import IntermediateResponse
 from sila2.framework.command.parameter import Parameter
 from sila2.framework.command.response import Response
+from sila2.framework.pb2 import SiLAFramework_pb2
+from sila2.framework.pb2.SiLAFramework_pb2 import Binary as SilaBinary
 from sila2.framework.property.property import Property
 
 if TYPE_CHECKING:
     from sila2.framework.feature import Feature
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import Binary as SilaBinary
 
 
-class Binary(DataType):
-    native_type = bytes
+class Binary(DataType[SilaBinary, bytes]):
     parent_feature: Feature
-    binary_transfer_possible: bool
     MAX_SIZE = 2 * 1024**2
-    message_type: Type[SilaBinary]
 
     def __init__(self, parent_feature: Feature, silaframework_pb2_module: SiLAFramework_pb2):
         self.message_type = silaframework_pb2_module.Binary
