@@ -18,6 +18,7 @@ from lxml import etree
 from lxml.etree import XSLT, XMLParser, XMLSchema, XSLTApplyError, _Element
 
 from sila2 import resource_dir
+from sila2.framework.pb2.custom_protocols import FeatureProtobufModule
 
 if TYPE_CHECKING:
     from sila2.framework.abc.sila_error import SilaError
@@ -59,13 +60,29 @@ class FullyQualifiedIdentifierRegex:
     IntermediateCommandResponseIdentifier = "/".join((__command_identifier, "IntermediateResponse", __identifier))
     DefinedExecutionErrorIdentifier = "/".join((__feature_identifier, "DefinedExecutionError", __identifier))
     PropertyIdentifier = "/".join((__feature_identifier, "Property", __identifier))
-    TypeIdentifier = "/".join((__feature_identifier, "DataType", __identifier))
+    DataTypeIdentifier = "/".join((__feature_identifier, "DataType", __identifier))
     MetadataIdentifier = "/".join((__feature_identifier, "Metadata", __identifier))
 
 
-def parse_feature_definition(feature_definition: str):
+def parse_feature_definition(feature_definition: str) -> etree._Element:
+    """
+    Parse a feature definition (content of a .sila.xml file) and return the root node of the XML document
+
+    Parameters
+    ----------
+    feature_definition
+        Feature definition (XML) as string, or path to a feature definition file
+
+    Returns
+    -------
+    fdl_root
+        Root node of the XML document
+    """
     schema = XMLSchema(etree.parse(join(resource_dir, "xsd", "FeatureDefinition.xsd")))
-    parser = XMLParser(schema=schema)
+    parser = XMLParser(schema=schema, encoding="utf-8")
+    if os.path.isfile(feature_definition) or feature_definition.endswith(".sila.xml"):
+        with open(feature_definition) as fdl_file:
+            feature_definition = fdl_file.read().lstrip("\ufeff")  # strip byte order mark, if exists
     return etree.fromstring(feature_definition.encode("utf-8"), parser=parser)
 
 
@@ -74,7 +91,7 @@ def xpath_sila(node, expression: str):
     return node.xpath(expression, namespaces=dict(sila="http://www.sila-standard.org"))
 
 
-def run_protoc(proto_file: str) -> Tuple[ModuleType, ModuleType]:
+def run_protoc(proto_file: str) -> Tuple[FeatureProtobufModule, ModuleType]:
     path, filename = os.path.split(abspath(proto_file))
     modulename, _ = os.path.splitext(filename)
 
@@ -93,7 +110,7 @@ def run_protoc(proto_file: str) -> Tuple[ModuleType, ModuleType]:
             raise RuntimeError(f"Failed to compile proto file {proto_file}")
 
         with temporarily_add_to_path(tmp_dir):
-            pb2_module = import_module(f"{modulename}_pb2")
+            pb2_module: FeatureProtobufModule = import_module(f"{modulename}_pb2")
             grpc_module = import_module(f"{modulename}_pb2_grpc")
 
         del sys.modules[pb2_module.__name__]
@@ -102,15 +119,19 @@ def run_protoc(proto_file: str) -> Tuple[ModuleType, ModuleType]:
         return pb2_module, grpc_module
 
 
-def feature_definition_to_modules(fdl_node) -> Tuple[ModuleType, ModuleType]:
+def feature_definition_to_proto_string(fdl_node) -> str:
     xslt = XSLT(etree.parse(join(resource_dir, "xsl", "fdl2proto.xsl")))
-    feature_id = xpath_sila(fdl_node, "sila:Identifier")[0].text
 
     try:
-        proto_str = str(xslt(fdl_node))
+        return str(xslt(fdl_node))
     except XSLTApplyError as ex:
-        raise ValueError(f"Invalid feature definition {feature_id}: {ex}")
+        raise ValueError(f"Invalid feature definition: {ex}")
 
+
+def feature_definition_to_modules(fdl_node) -> Tuple[FeatureProtobufModule, ModuleType]:
+    proto_str = feature_definition_to_proto_string(fdl_node)
+
+    feature_id = xpath_sila(fdl_node, "sila:Identifier")[0].text
     with tempfile.TemporaryDirectory() as tmp_dir:
         proto_file = join(tmp_dir, f"{feature_id}.proto")
         with open(proto_file, "w", encoding="utf-8") as proto_fp:
