@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 from datetime import datetime, timedelta
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, List, Optional, Union
 
 from sila2.features.lockcontroller import (
     InvalidLockIdentifier,
@@ -13,6 +13,7 @@ from sila2.features.lockcontroller import (
 )
 from sila2.framework import Command, Feature, FullyQualifiedIdentifier, Property
 from sila2.server import MetadataInterceptor, SilaServer
+from sila2.server.metadata_dict import MetadataDict
 
 
 @dataclass
@@ -42,21 +43,17 @@ class LockControllerImpl(LockControllerBase):
 
         return self.lock is not None
 
-    def get_IsLocked(self, *, metadata: Dict[FullyQualifiedIdentifier, Any]) -> bool:
+    def get_IsLocked(self, *, metadata: MetadataDict) -> bool:
         return self.is_locked
 
-    def LockServer(
-        self, LockIdentifier: str, Timeout: int, *, metadata: Dict[FullyQualifiedIdentifier, Any]
-    ) -> LockServer_Responses:
+    def LockServer(self, LockIdentifier: str, Timeout: int, *, metadata: MetadataDict) -> LockServer_Responses:
         if self.is_locked:
             raise ServerAlreadyLocked
 
         self.lock = Lock(LockIdentifier, timedelta(seconds=Timeout))
         return LockServer_Responses()
 
-    def UnlockServer(
-        self, LockIdentifier: str, *, metadata: Dict[FullyQualifiedIdentifier, Any]
-    ) -> UnlockServer_Responses:
+    def UnlockServer(self, LockIdentifier: str, *, metadata: MetadataDict) -> UnlockServer_Responses:
         if not self.is_locked:
             raise ServerNotLocked
 
@@ -76,13 +73,10 @@ class LockControllerImpl(LockControllerBase):
 
 class LockControllerInterceptor(MetadataInterceptor):
     def __init__(self, lockcontroller_impl: LockControllerImpl):
-        self.lockidentifier_fqi = LockControllerFeature["LockIdentifier"].fully_qualified_identifier
-        super().__init__([self.lockidentifier_fqi])
+        super().__init__([LockControllerFeature["LockIdentifier"]])
         self.lockcontroller_impl = lockcontroller_impl
 
-    def intercept(
-        self, parameters: Any, metadata: Dict[FullyQualifiedIdentifier, Any], target_call: FullyQualifiedIdentifier
-    ) -> None:
-        token: str = metadata.pop(self.lockidentifier_fqi)
+    def intercept(self, parameters: Any, metadata: MetadataDict, target_call: FullyQualifiedIdentifier) -> None:
+        token: str = metadata[LockControllerFeature["LockIdentifier"]]
         if token != self.lockcontroller_impl.lock.token:
             raise InvalidLockIdentifier
